//---------------------------------------------------------------------------------
/// \file	MyFunction.h
/// \author	Rob Bateman [robthebloke@hotmail.com]
/// \date	2-7-2004
/// \brief	This aims to improve the basic functionality of our plugin by adding
/// 		a -selected / -sl flag to only apply the lights to the selected meshes.
/// 		This requires a bit of basic argument parsing.
///
//---------------------------------------------------------------------------------

#ifndef __MY_MEL_COMMAND__H__
#define __MY_MEL_COMMAND__H__

	#ifdef WIN32
		#define NT_PLUGIN
		#pragma once
	#endif

	// include any maya headers we need.
	#include <maya/MPxCommand.h>
	#include <maya/MGlobal.h>
	#include <maya/MFnMesh.h>
	#include <maya/MFnTransform.h>
	#include <maya/MFnPointLight.h>
	#include <maya/MItDependencyNodes.h>
	#include <maya/MPointArray.h>

	class MyFunction
		: public MPxCommand {
	public:

		/// \brief	This function is overidden to tell maya whether this mel command
		/// 		can be undone. To keep things simple, returning false indicates to
		/// 		maya that this command will not undo itself.../
		/// \return	false
		///
		virtual bool isUndoable() const ;

		/// \brief	This function is called when you mel command is executed. The function
		/// 		recieves the list of arguments passed to the command by mel.
		/// \param	args	-	the list of arguments
		/// \param	An error code.
		///
		MStatus doIt( const MArgList& args );


		/// \brief	this function is called by maya to return a new instance of our mel function
		/// \return	the new mel command object
		///
		static void* creator();

	private:

		/// \brief	an internal function to simply add a set of lights to the mesh object
		/// 		specified.
		/// \param	oMesh	-	the handle to the object to attach the lights to
		/// \return	a status code
		///
		MStatus addLightsToMesh(MObject oMesh);
	};

#endif
