#include "MyFunction.h"
#include <maya/MFnPlugin.h>

// required to link the libraries
#ifdef WIN32
	#pragma comment(lib,"Foundation.lib")
	#pragma comment(lib,"OpenMaya.lib")
	#pragma comment(lib,"OpenMayaFx.lib")
	#pragma comment(lib,"OpenMayaUi.lib")
	#pragma comment(lib,"Image.lib")
	#pragma comment(lib,"OpenMayaAnim.lib")
#endif

// under WIN32 we have to 'export' these functions so that they are visible
// inside the dll. If maya can't see the functions, it can't load the plugin!
#ifdef WIN32
	#define EXPORT __declspec(dllexport)
#else
	#define EXPORT
#endif


/// \brief	This function is called once when our plugin is loaded. We can use
///			it to register any custom nodes, mel functions etc.
/// \param	obj	-	a handle to the loaded plugin
/// \return	an MStatus error code
///
EXPORT MStatus initializePlugin( MObject obj )
{
	MStatus stat;

	// we need to use the plugin function set to register a new mel command with maya.
	// we can provide some info about the author of the plugin, the version number, and we
	// can also specify a required version of maya, though usually "Any" will do...
	//
	MFnPlugin fnPlugin( obj, "Rob Bateman", "1.0", "Any");

	// register our new mel command with maya
	//
	stat = fnPlugin.registerCommand( "myFunction",
								  MyFunction::creator,
								  NULL );

	// check for error
	if( stat != MS::kSuccess )
		stat.perror( "could not register the \"myFunction\" mel command" );

	return stat;
}

/// \brief	This function is called once when our plugin is unloaded. We need
/// 		to tell maya which mel funcs, nodes etc we are removing.
/// \param	obj	-	a handle to the loaded plugin
/// \return	an MStatus error code
///
EXPORT MStatus uninitializePlugin( MObject obj)
{
	MStatus stat;

	// use the plugin function set to unload the plugin
	MFnPlugin fnPlugin( obj );

	// deregister the mel command
	stat = fnPlugin.deregisterCommand( "myFunction" );

	// check for error
	if( stat != MS::kSuccess )
		stat.perror( "could not de-register the \"myFunction mel\" command" );

	return stat;
}
